@@ -52,7 +52,7 @@ class SpigetAPI:
         Call an API endpoint
 
         :param endpoint: The endpoint to call
-        :param params: POST request body (optional)
+        :param params: Request body as a dict (optional)
         :returns: A Response object
         """
         if params is None:
@@ -154,7 +154,7 @@ class SpigetAPI:
             return {
                 "status": False,
                 "message": "Could not download resource due to an unknown error. "
-                           "This can sometimes happen with external resources.",
+                "This can sometimes happen with external resources.",
             }
 
         if not filename:
@@ -167,7 +167,7 @@ class SpigetAPI:
 
         Utils.inject_metadata_file(plugin, plugin_jar_name)
 
-        return {"status": True, "message": ""}
+        return {"status": True, "message": f"Downloaded {plugin_jar_name}"}
 
     def get_plugin_info_if_update(self, metadata: Metadata) -> Union[Plugin, None]:
         """
@@ -201,7 +201,7 @@ class SpigetAPI:
         Get information about the latest update of a plugin
 
         :param plugin: A Plugin dict
-        :returns: An Update dict
+        :return: An Update dict
         """
         response = self.call_api(f"/resources/{plugin['id']}/updates/latest")
         response.raise_for_status()
@@ -214,10 +214,14 @@ class SpigetAPI:
             BeautifulSoup(update["description"], "html.parser").stripped_strings
         )
         # Remove duplicate newlines and spaces
-        update["description"] = update["description"].replace("  ", " ")
-        update["description"] = update["description"].replace("\r\n", "\n")
-        update["description"] = update["description"].replace("\n\n", "\n")
+        update["description"] = (
+            update["description"]
+            .replace("  ", " ")
+            .replace("\r\n", "\n")
+            .replace("\n\n", "\n")
+        )
 
+        # Truncate description to 1500 chars to avoid terminal spam
         if len(update["description"]) > 1500:
             update["description"] = update["description"][:1500] + "..."
         return update
